/*
 * Copyright (c) 2005-2007 CodeDroids ApS (http://www.codedroids.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * For further information about CodeDroids ApS, please see the
 * company website: http://www.codedroids.com
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * $LastChangedRevision: 118 $
 * $LastChangedDate: 2007-02-20 17:26:56 +0100 (Tue, 20 Feb 2007) $
 * 
 */

package com.codedroids.fm.records;

import java.util.*;
import com.codedroids.records.I_Record;
import com.codedroids.records.RecordField;
import freemarker.template.SimpleHash;

/**
 * Needed to wrap Generic records for use with FreeMarker (MapRecord and BeanRecords works without this wrapper)
 * freemarker.jar is needed to compile, optional at runtime.
 */
public class RecordHash extends SimpleHash {
	
	static final long serialVersionUID = 1L;
	
	public RecordHash() {
		super();
	}
	
	// Caches record value in the parent map, this ensures the correct wrapping is performed
	// and it is performed only once.
	public RecordHash(I_Record rec) {
		this();
		Iterator i = rec.factory().getFields().values().iterator();
		while(i.hasNext()) {
			RecordField f = (RecordField)i.next();
			Object v = rec.valueForField(f);
			this.put(f.getName(), v);
		}
	}

	// convenience to extend the records number of fields if needed
	public RecordHash(I_Record rec, Map extra) {
		this(rec);
        this.putAll(extra);
	}
}
